@@ -29,6 +29,7 @@ from swecli.ui.conversation import ConversationBuffer
 from swecli.ui.key_bindings import KeyBindingManager
 from swecli.ui.approval_modal import ApprovalModalManager
 from swecli.ui.model_selector_modal import ModelSelectorModalManager
+from swecli.ui.mcp_viewer_modal import MCPViewerModalManager
 from swecli.ui.layout_manager import LayoutManager
 
 
@@ -75,7 +76,7 @@ class ChatApplication:
 
         # Create input buffer (where user types)
         self.input_buffer = Buffer(
-            multiline=False,
+            multiline=True,
             completer=completer,
             on_text_insert=self._on_text_insert,
             on_text_changed=self._on_buffer_text_changed,
@@ -97,6 +98,9 @@ class ChatApplication:
         # Create model selector modal manager
         self.model_selector_modal_manager = ModelSelectorModalManager(self)
 
+        # Create MCP viewer modal manager
+        self.mcp_viewer_modal_manager = MCPViewerModalManager(self)
+
         # Create style
         self.style = self._create_style()
 
@@ -150,6 +154,12 @@ class ChatApplication:
 
     def _get_status_text(self) -> StyleAndTextTuples:
         """Get status bar text."""
+        # Show exit confirmation message if in exit confirmation mode
+        if self._exit_confirmation_mode:
+            return [
+                ("class:exit-confirmation", "Press Ctrl+C again to exit"),
+            ]
+
         # TODO: Connect to actual mode and context info
         return [
             ("", "⏵⏵ normal mode  •  Context: 95%  •  Ctrl+C to exit"),
@@ -158,6 +168,11 @@ class ChatApplication:
     def _on_text_insert(self, buffer: Buffer) -> None:
         """Handle text insertion - detect large pastes and replace with placeholder."""
         # Note: No need to check approval mode here - keys are blocked at key binding level
+
+        # Cancel exit confirmation mode if user starts typing
+        if self._exit_confirmation_mode:
+            self._cancel_exit_confirmation()
+
         text = buffer.text
 
         # Detect large paste (content longer than threshold)
@@ -435,6 +450,27 @@ class ChatApplication:
         """Check if selector mode is active."""
         return self.model_selector_modal_manager.is_in_selector_mode()
 
+    def _handle_viewer_up(self):
+        """Handle up arrow in MCP viewer mode."""
+        return self.mcp_viewer_modal_manager.handle_viewer_up()
+
+    def _handle_viewer_down(self):
+        """Handle down arrow in MCP viewer mode."""
+        return self.mcp_viewer_modal_manager.handle_viewer_down()
+
+    def _handle_viewer_enter(self):
+        """Handle enter in MCP viewer mode."""
+        return self.mcp_viewer_modal_manager.handle_viewer_enter()
+
+    def _handle_viewer_escape(self):
+        """Handle escape in MCP viewer mode."""
+        return self.mcp_viewer_modal_manager.handle_viewer_escape()
+
+    @property
+    def _viewer_mode(self) -> bool:
+        """Check if MCP viewer mode is active."""
+        return self.mcp_viewer_modal_manager.is_in_viewer_mode()
+
     def run(self) -> None:
         """Run the chat application."""
         # Simply let prompt_toolkit handle everything
